==> base-domain-0.0.1-20161020.081216-9-sources.jar: com/thebeastshop/scm/po/Product.java <==
package com.thebeastshop.scm.po;

import java.math.BigDecimal;

import pers.richard.ormybatis.domain.po.IdPo;

public class Product extends IdPo {
	private String code;
	private BigDecimal listPrice;
	private Integer allowVipDiscount;
	private Integer allowNoteCard;
	private Integer prepareDays;
	private Integer selectDeliveryDays;
	private String canDeliveryDays;
	private String canNotDeliveryDays;
	private Integer expressType;
	private String picList;
	private String picDetail;
	private String picThumb;
	private String name;
	private String nameCn;
	private String skuCategoryDesc;
	private String picDetailMul;
	private Integer sort2;
	private Integer sort1;
	private Integer seq;
	private String description;
	
	public Product(){}
	
	public final static String
		F_CODE = "CODE",
		F_LIST_PRICE = "LIST_PRICE",
		F_ALLOW_VIP_DISCOUNT = "ALLOW_VIP_DISCOUNT",
		F_ALLOW_NOTE_CARD = "ALLOW_NOTE_CARD",
		F_PREPARE_DAYS = "PREPARE_DAYS",
		F_SELECT_DELIVERY_DAYS = "SELECT_DELIVERY_DAYS",
		F_CAN_DELIVERY_DAYS = "CAN_DELIVERY_DAYS",
		F_CAN_NOT_DELIVERY_DAYS = "CAN_NOT_DELIVERY_DAYS",
		F_EXPRESS_TYPE = "EXPRESS_TYPE",
		F_PIC_LIST = "PIC_LIST",
		F_PIC_DETAIL = "PIC_DETAIL",
		F_PIC_THUMB = "PIC_THUMB",
		F_NAME = "NAME",
		F_NAME_CN = "NAME_CN",
		F_SKU_CATEGORY_DESC = "SKU_CATEGORY_DESC",
		F_PIC_DETAIL_MUL = "PIC_DETAIL_MUL",
		F_SORT2 = "SORT2",
		F_SORT1 = "SORT1",
		F_SEQ = "SEQ",
		F_DESCRIPTION = "DESCRIPTION";
	
	public String getCode() {return code;}
	public void setCode(String code) {this.code = code;}

	public BigDecimal getListPrice() {return listPrice;}
	public void setListPrice(BigDecimal listPrice) {this.listPrice = listPrice;}

	public Integer getAllowVipDiscount() {return allowVipDiscount;}
	public void setAllowVipDiscount(Integer allowVipDiscount) {this.allowVipDiscount = allowVipDiscount;}

	public Integer getAllowNoteCard() {return allowNoteCard;}
	public void setAllowNoteCard(Integer allowNoteCard) {this.allowNoteCard = allowNoteCard;}

	public Integer getPrepareDays() {return prepareDays;}
	public void setPrepareDays(Integer prepareDays) {this.prepareDays = prepareDays;}

	public Integer getSelectDeliveryDays() {return selectDeliveryDays;}
	public void setSelectDeliveryDays(Integer selectDeliveryDays) {this.selectDeliveryDays = selectDeliveryDays;}

	public String getCanDeliveryDays() {return canDeliveryDays;}
	public void setCanDeliveryDays(String canDeliveryDays) {this.canDeliveryDays = canDeliveryDays;}

	public String getCanNotDeliveryDays() {return canNotDeliveryDays;}
	public void setCanNotDeliveryDays(String canNotDeliveryDays) {this.canNotDeliveryDays = canNotDeliveryDays;}

	public Integer getExpressType() {return expressType;}
	public void setExpressType(Integer expressType) {this.expressType = expressType;}

	public String getPicList() {return picList;}
	public void setPicList(String picList) {this.picList = picList;}

	public String getPicDetail() {return picDetail;}
	public void setPicDetail(String picDetail) {this.picDetail = picDetail;}

	public String getPicThumb() {return picThumb;}
	public void setPicThumb(String picThumb) {this.picThumb = picThumb;}

	public String getName() {return name;}
	public void setName(String name) {this.name = name;}

	public String getNameCn() {return nameCn;}
	public void setNameCn(String nameCn) {this.nameCn = nameCn;}

	public String getSkuCategoryDesc() {return skuCategoryDesc;}
	public void setSkuCategoryDesc(String skuCategoryDesc) {this.skuCategoryDesc = skuCategoryDesc;}

	public String getPicDetailMul() {return picDetailMul;}
	public void setPicDetailMul(String picDetailMul) {this.picDetailMul = picDetailMul;}

	public Integer getSort2() {return sort2;}
	public void setSort2(Integer sort2) {this.sort2 = sort2;}

	public Integer getSort1() {return sort1;}
	public void setSort1(Integer sort1) {this.sort1 = sort1;}

	public Integer getSeq() {return seq;}
	public void setSeq(Integer seq) {this.seq = seq;}

	public String getDescription() {return description;}
	public void setDescription(String description) {this.description = description;}
	
	
}

==> base-domain-0.0.1-20161024.103639-19-sources.jar: com/thebeastshop/scm/po/Product.java <==
package com.thebeastshop.scm.po;

import java.math.BigDecimal;

import com.thebeastshop.scm.po.ChnCanSaleProd.OnShelf;

import pers.richard.ormybatis.domain.po.IdPo;

public class Product extends IdPo {
	private String code;
	private Integer conbined;
	private BigDecimal listPrice;
	private Integer allowVipDiscount;
	private Integer allowNoteCard;
	private Integer prepareDays;
	private Integer selectDeliveryDays;
	private String canDeliveryDays;
	private String canNotDeliveryDays;
	private Integer expressType;
	private String picList;
	private String picDetail;
	private String picThumb;
	private String name;
	private String nameCn;
	private String skuCategoryDesc;
	private String picDetailMul;
	private Integer sort2;
	private Integer sort1;
	private Integer seq;
	private String description;
	private String status;
	
	public Product(){}
	
	public enum Status{
		
	}

	
	public final static String
		F_CODE = "CODE",
		F_CONBINED = "conbined",
		F_LIST_PRICE = "LIST_PRICE",
		F_ALLOW_VIP_DISCOUNT = "ALLOW_VIP_DISCOUNT",
		F_ALLOW_NOTE_CARD = "ALLOW_NOTE_CARD",
		F_PREPARE_DAYS = "PREPARE_DAYS",
		F_SELECT_DELIVERY_DAYS = "SELECT_DELIVERY_DAYS",
		F_CAN_DELIVERY_DAYS = "CAN_DELIVERY_DAYS",
		F_CAN_NOT_DELIVERY_DAYS = "CAN_NOT_DELIVERY_DAYS",
		F_EXPRESS_TYPE = "EXPRESS_TYPE",
		F_PIC_LIST = "PIC_LIST",
		F_PIC_DETAIL = "PIC_DETAIL",
		F_PIC_THUMB = "PIC_THUMB",
		F_NAME = "NAME",
		F_NAME_CN = "NAME_CN",
		F_SKU_CATEGORY_DESC = "SKU_CATEGORY_DESC",
		F_PIC_DETAIL_MUL = "PIC_DETAIL_MUL",
		F_SORT2 = "SORT2",
		F_SORT1 = "SORT1",
		F_SEQ = "SEQ",
		F_DESCRIPTION = "DESCRIPTION",
		F_STATUS = "status";
	
	public String getCode() {return code;}
	public void setCode(String code) {this.code = code;}

	public Integer getConbined() {return conbined;}
	public void setConbined(Integer conbined) {this.conbined = conbined;}
	
	public BigDecimal getListPrice() {return listPrice;}
	public void setListPrice(BigDecimal listPrice) {this.listPrice = listPrice;}

	public Integer getAllowVipDiscount() {return allowVipDiscount;}
	public void setAllowVipDiscount(Integer allowVipDiscount) {this.allowVipDiscount = allowVipDiscount;}

	public Integer getAllowNoteCard() {return allowNoteCard;}
	public void setAllowNoteCard(Integer allowNoteCard) {this.allowNoteCard = allowNoteCard;}

	public Integer getPrepareDays() {return prepareDays;}
	public void setPrepareDays(Integer prepareDays) {this.prepareDays = prepareDays;}

	public Integer getSelectDeliveryDays() {return selectDeliveryDays;}
	public void setSelectDeliveryDays(Integer selectDeliveryDays) {this.selectDeliveryDays = selectDeliveryDays;}

	public String getCanDeliveryDays() {return canDeliveryDays;}
	public void setCanDeliveryDays(String canDeliveryDays) {this.canDeliveryDays = canDeliveryDays;}

	public String getCanNotDeliveryDays() {return canNotDeliveryDays;}
	public void setCanNotDeliveryDays(String canNotDeliveryDays) {this.canNotDeliveryDays = canNotDeliveryDays;}

	public Integer getExpressType() {return expressType;}
	public void setExpressType(Integer expressType) {this.expressType = expressType;}

	public String getPicList() {return picList;}
	public void setPicList(String picList) {this.picList = picList;}

	public String getPicDetail() {return picDetail;}
	public void setPicDetail(String picDetail) {this.picDetail = picDetail;}

	public String getPicThumb() {return picThumb;}
	public void setPicThumb(String picThumb) {this.picThumb = picThumb;}

	public String getName() {return name;}
	public void setName(String name) {this.name = name;}

	public String getNameCn() {return nameCn;}
	public void setNameCn(String nameCn) {this.nameCn = nameCn;}

	public String getSkuCategoryDesc() {return skuCategoryDesc;}
	public void setSkuCategoryDesc(String skuCategoryDesc) {this.skuCategoryDesc = skuCategoryDesc;}

	public String getPicDetailMul() {return picDetailMul;}
	public void setPicDetailMul(String picDetailMul) {this.picDetailMul = picDetailMul;}

	public Integer getSort2() {return sort2;}
	public void setSort2(Integer sort2) {this.sort2 = sort2;}

	public Integer getSort1() {return sort1;}
	public void setSort1(Integer sort1) {this.sort1 = sort1;}

	public Integer getSeq() {return seq;}
	public void setSeq(Integer seq) {this.seq = seq;}

	public String getDescription() {return description;}
	public void setDescription(String description) {this.description = description;}
	
	public String getStatus() {return status;}
	public void setStatus(String status) {this.status = status;}
}
